Package: SCIproj
Type: Package
Title: Creates a Scientific Project Skeleton as an R Package
Version: 1.0.1
Authors@R: c(person("Saskia", "Otto", email = "saskia.a.otto@gmail.com",
    role = c("aut","cre", "cph"),
    comment = c(ORCID = "0000-0001-7780-1322")))
Description: Provides a template for new research projects structured as an R
    package-based research compendium. Everything - data, R scripts, custom
    functions and manuscript or reports - is contained within the same package to
    facilitate collaboration and promote reproducible research, following the FAIR 
    principles.
Language: en-US
License: MIT + file LICENSE
Depends: R(>= 4.1.0)
Imports: usethis (>= 2.0.0), rstudioapi, cli
Suggests: knitr, renv, rmarkdown, targets, testthat (>= 3.0.0), withr
VignetteBuilder: knitr
Config/testthat/edition: 3
RoxygenNote: 7.3.3
Encoding: UTF-8
URL: https://github.com/saskiaotto/SCIproj
BugReports: https://github.com/saskiaotto/SCIproj/issues
NeedsCompilation: no
Packaged: 2026-04-22 12:08:57 UTC; saskiaotto
Author: Saskia Otto [aut, cre, cph] (ORCID:
    <https://orcid.org/0000-0001-7780-1322>)
Maintainer: Saskia Otto <saskia.a.otto@gmail.com>
Repository: CRAN
Date/Publication: 2026-04-22 12:30:15 UTC
Built: R 4.6.0; ; 2026-04-29 07:42:20 UTC; unix
