Place here original (raw) data (e.g. in csv or txt format), together with R scripts used for data preparation. Use either individual scripts or use the clean_data.R file for all.
Clean data produced by those R scripts go to the `data` folder.
