## ----include = FALSE----------------------------------------------------------
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>"
)

## ----install, eval = FALSE----------------------------------------------------
# # install.packages("remotes")
# remotes::install_github("saskiaotto/SCIproj")

## ----basic, eval = FALSE------------------------------------------------------
# library(SCIproj)
# create_proj("~/projects/my_analysis")

## ----custom, eval = FALSE-----------------------------------------------------
# create_proj("~/projects/baltic_cod",
#   add_license = "MIT",
#   license_holder = "Jane Doe",
#   orcid = "0000-0001-2345-6789",
#   use_docker = TRUE,
#   use_git = TRUE
# )

## ----citation, eval = FALSE---------------------------------------------------
# create_proj("my_project",
#   license_holder = "Jane Doe",
#   orcid = "0000-0001-2345-6789",
#   add_license = "MIT"
# )

## ----targets, eval = FALSE----------------------------------------------------
# # 1. Define targets in _targets.R
# # 2. Inspect the pipeline
# targets::tar_manifest()
# targets::tar_visnetwork()
# # 3. Run the pipeline
# targets::tar_make()
# # 4. Read a result
# targets::tar_read(my_result)

## ----renv, eval = FALSE-------------------------------------------------------
# renv::status()     # check if lockfile is in sync
# renv::snapshot()   # update the lockfile after adding packages
# renv::restore()    # reinstall packages from the lockfile

## ----github, eval = FALSE-----------------------------------------------------
# create_proj("my_project",
#   use_git = TRUE,
#   create_github_repo = TRUE,
#   ci = "gh-actions"
# )

