#' SCIproj package
#'
#' Generic template for research projects structured as R packages.
#' This package works as a template for new research projects,
#' under the idea of having everything (data, R scripts, functions and manuscripts)
#' contained in the same package to promote reproducible research.
#'
#' @name SCIproj-package
#' @docType package
#' @author Saskia A. Otto
#' @details For detailed steps on how to use the package see \url{https://github.com/saskiaotto/SCIproj/blob/main/README.md}.
#' @keywords internal
"_PACKAGE"
#'
NULL
