# Data Sources

Document the provenances of all raw datasets used in this project.

## Dataset 1: [Name]

| Field            | Value                          |
|------------------|--------------------------------|
| **Source**       | [Organisation / database name] |
| **URL**          | [Download URL]                 |
| **DOI**          | [DOI if available]             |
| **License**      | [Data license, e.g. CC BY 4.0] |
| **Download date**| [YYYY-MM-DD]                   |
| **File(s)**      | [filename1.csv, filename2.csv] |
| **Description**  | [Brief description]            |

## Dataset 2: [Name]

| Field            | Value                           |
|------------------|---------------------------------|
| **Source**       |                                 |
| **URL**          |                                 |
| **DOI**          |                                 |
| **License**      |                                 |
| **Download date**|                                 |
| **File(s)**      |                                 |
| **Description**  |                                 |
