% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{clean_pkg_name}
\alias{clean_pkg_name}
\title{Clean a directory name into a valid R package name}
\usage{
clean_pkg_name(name)
}
\arguments{
\item{name}{Character. The directory name to clean.}
}
\value{
A valid R package name.
}
\description{
Converts underscores and hyphens to dots and removes other invalid
characters. R package names may only contain letters, numbers, and dots,
must start with a letter, and must not end with a dot.
}
\keyword{internal}
